@@ -23,15 +23,16 @@ else:
 __all__ = (
     "BatchGetRecordErrorTypeDef",
     "BatchGetRecordIdentifierTypeDef",
-    "BatchGetRecordRequestRequestTypeDef",
-    "BatchGetRecordResponseTypeDef",
-    "BatchGetRecordResultDetailTypeDef",
-    "DeleteRecordRequestRequestTypeDef",
+    "ResponseMetadataTypeDef",
     "FeatureValueTypeDef",
+    "DeleteRecordRequestRequestTypeDef",
     "GetRecordRequestRequestTypeDef",
+    "BatchGetRecordRequestRequestTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "BatchGetRecordResultDetailTypeDef",
     "GetRecordResponseTypeDef",
     "PutRecordRequestRequestTypeDef",
-    "ResponseMetadataTypeDef",
+    "BatchGetRecordResponseTypeDef",
 )
 
 BatchGetRecordErrorTypeDef = TypedDict(
@@ -66,29 +67,22 @@ class BatchGetRecordIdentifierTypeDef(
     pass
 
 
-BatchGetRecordRequestRequestTypeDef = TypedDict(
-    "BatchGetRecordRequestRequestTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "Identifiers": Sequence["BatchGetRecordIdentifierTypeDef"],
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-BatchGetRecordResponseTypeDef = TypedDict(
-    "BatchGetRecordResponseTypeDef",
+FeatureValueTypeDef = TypedDict(
+    "FeatureValueTypeDef",
     {
-        "Records": List["BatchGetRecordResultDetailTypeDef"],
-        "Errors": List["BatchGetRecordErrorTypeDef"],
-        "UnprocessedIdentifiers": List["BatchGetRecordIdentifierTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-BatchGetRecordResultDetailTypeDef = TypedDict(
-    "BatchGetRecordResultDetailTypeDef",
-    {
-        "FeatureGroupName": str,
-        "RecordIdentifierValueAsString": str,
-        "Record": List["FeatureValueTypeDef"],
+        "FeatureName": str,
+        "ValueAsString": str,
     },
 )
 
@@ -101,14 +95,6 @@ DeleteRecordRequestRequestTypeDef = TypedDict(
     },
 )
 
-FeatureValueTypeDef = TypedDict(
-    "FeatureValueTypeDef",
-    {
-        "FeatureName": str,
-        "ValueAsString": str,
-    },
-)
-
 _RequiredGetRecordRequestRequestTypeDef = TypedDict(
     "_RequiredGetRecordRequestRequestTypeDef",
     {
@@ -131,11 +117,34 @@ class GetRecordRequestRequestTypeDef(
     pass
 
 
+BatchGetRecordRequestRequestTypeDef = TypedDict(
+    "BatchGetRecordRequestRequestTypeDef",
+    {
+        "Identifiers": Sequence[BatchGetRecordIdentifierTypeDef],
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+BatchGetRecordResultDetailTypeDef = TypedDict(
+    "BatchGetRecordResultDetailTypeDef",
+    {
+        "FeatureGroupName": str,
+        "RecordIdentifierValueAsString": str,
+        "Record": List[FeatureValueTypeDef],
+    },
+)
+
 GetRecordResponseTypeDef = TypedDict(
     "GetRecordResponseTypeDef",
     {
-        "Record": List["FeatureValueTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Record": List[FeatureValueTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -143,17 +152,16 @@ PutRecordRequestRequestTypeDef = TypedDict(
     "PutRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
-        "Record": Sequence["FeatureValueTypeDef"],
+        "Record": Sequence[FeatureValueTypeDef],
     },
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+BatchGetRecordResponseTypeDef = TypedDict(
+    "BatchGetRecordResponseTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "Records": List[BatchGetRecordResultDetailTypeDef],
+        "Errors": List[BatchGetRecordErrorTypeDef],
+        "UnprocessedIdentifiers": List[BatchGetRecordIdentifierTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
